noop

package
v1.10.18 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 11, 2025 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package noop is an implementation of Compression interface that doesn't compress data.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Noop

type Noop struct{}

Noop is an implementation of Compression interface that doesn't compress data.

func New

func New() Noop

New creates a new instance of Noop.

func (Noop) Compress

func (z Noop) Compress(data []byte) ([]byte, error)

Compress will return given data without any compression.

Jump to